@@ -1,6 +1,6 @@
 /*                               -*- Mode: C -*- 
  * $Basename: ircfiles.c $
- * $Revision: 1.6.1.13.1.4 $
+ * $Revision: 1.6.1.13.1.5 $
  * Author          : Brewster@think.com
  * Created On      : 7/90
  * Last Modified By: Ulrich Pfeifer
@@ -3662,6 +3662,11 @@ void fields_header_function(line)
 
   if(number_not_ended_section > 0) {
     if(match(tmpline,&end_pos,NULL,Ltable->layout[Lpos].end_tag_pos)){
+
+      /* Carl Lagoze 9/1/98
+	 Bug discovered!! If we match the end pattern then we should always
+	 turn off number_not_ended_section */
+      number_not_ended_section = 0;
       if(end_pos > 0) {
         tmpline[MINIMUM(end_pos,MAX_LINE_LENGTH)] = '\0';
         while (tmpline[i] && (isspace(tmpline[i]) || (tmpline[i] == '\t'))) i++;
@@ -3788,6 +3793,10 @@ char *header;
 {
   int i;
 
+  /* Carl Lagoze 9/1/98
+     Bug Discovered!!  When we finish a record we should always turn off
+     number_not_ended_section */
+  number_not_ended_section = 0;
   for (i=0;i<=MAX_HEADER_LEN;i++) {
     if (fields_header[i]) 
       if (fields_header[i] == '\n')
