@@ -1,31 +1,16 @@
-/* WIDE AREA INFORMATION SERVER SOFTWARE:
-   No guarantees or restrictions.  See the readme file for the full standard
-   disclaimer.
-
-   This is part of the X user-interface for the WAIS software.  Do with it
-   as you please.
-
-   jonathan@Think.COM
-*/
-
-/* Copyright (c) CNIDR (see ../doc/CNIDR/COPYRIGHT) */
-
-/* $Log: xquestion.h,v $
- * Revision 2.0.1.1  1995/09/15 09:57:30  pfeifer
- * patch7: Fixed CNIDR copyright line.
- *
- * Revision 2.0  1995/09/08  08:07:23  pfeifer
- * Metaconfig baseline
- *
- * Revision 1.2  1994/08/05  07:31:02  pfeifer
- * Release beta 04
- *
- * Revision 1.1  1993/02/16  15:10:18  freewais
- * Initial revision
- *
- * Revision 1.4  92/03/17  14:19:56  jonathan
- * Separated from question.c.
+/*                               -*- Mode: C -*- 
+ * $Basename: xquestion.h $
+ * $Revision: 1.7.1.3 $
+ * Author          : jonathan@Think.COM
+ * Created On      : 92/03/17  14:19:56
+ * Last Modified By: Ulrich Pfeifer
+ * Last Modified On: Mon May  5 09:27:11 1997
+ * Language        : C
+ * Update Count    : 1
+ * Status          : Unknown, Use with caution!
  * 
+ * (C) Copyright 1997, Universitt Dortmund, all rights reserved.
+ * (C) Copyright CNIDR (see ../doc/CNIDR/COPYRIGHT)
  */
 
 #ifndef _H_XQUESTION
